@@ -14,6 +14,10 @@
 # Modified 16 May 2011 by Michaell Friendly
 #   - corrected bug introduced in dataEllipse via allowing pivot=TRUE 
 # Modified 7 Aug 2011 by J. Fox: added draw argument
+# Modified 28 Nov 2011  by J. Fox (suggested by Michael Friendly):
+#   - corrected bug in xlab, ylab in confidenceEllipse()
+#   - added dfn argument to .lm and .glm methods for confidenceEllipse()
+# Modified 14&16 Dec 2011 by J. Fox (suggested by Michael Friendly) to add weights argument to dataEllipse().
 
 ellipse <- function(center, shape, radius, log="", center.pch=19, center.cex=1.5, segments=51, draw=TRUE, add=draw, 
 		xlab="", ylab="", col=palette()[2], lwd=2, fill=FALSE, fill.alpha=0.3,
@@ -66,7 +70,7 @@ ellipse <- function(center, shape, radius, log="", center.pch=19, center.cex=1.5
 	invisible(ellipse)
 }
 
-dataEllipse <- function(x, y, log="", levels=c(0.5, 0.95), center.pch=19, 
+dataEllipse <- function(x, y, weights, log="", levels=c(0.5, 0.95), center.pch=19, 
 		center.cex=1.5, draw=TRUE,
 		plot.points=draw, add=!plot.points, segments=51, robust=FALSE, 
 		xlab=deparse(substitute(x)), ylab=deparse(substitute(y)), 
@@ -83,6 +87,8 @@ dataEllipse <- function(x, y, log="", levels=c(0.5, 0.95), center.pch=19,
 	}
 	else if(!(is.vector(x) && is.vector(y) && length(x) == length(y)))
 		stop("x and y must be vectors of the same length")
+	if (missing(weights)) weights <- rep(1, length(x))
+	if (length(weights) != length(x)) stop("weights must be of the same length as x and y")
 	if(draw) {
 		if (!add) {
 			plot(x, y, type="n", xlab=xlab, ylab=ylab,  ...) 
@@ -95,13 +101,15 @@ dataEllipse <- function(x, y, log="", levels=c(0.5, 0.95), center.pch=19,
 	dfn <- 2
 	dfd <- length(x) - 1
 	if (robust) {
-		v <- cov.trob(cbind(x, y))
+		use <- weights > 0
+		v <- cov.trob(cbind(x[use], y[use]), wt=weights[use])
 		shape <- v$cov
 		center <- v$center
 	}
 	else {
-		shape <- var(cbind(x, y))
-		center <- c(mean(x), mean(y))
+		v <- cov.wt(cbind(x, y), wt=weights)
+		shape <- v$cov
+		center <- v$center
 	}
 	result <- vector("list", length=length(levels))
 	names(result) <- levels
@@ -115,12 +123,11 @@ dataEllipse <- function(x, y, log="", levels=c(0.5, 0.95), center.pch=19,
 	invisible(if (length(levels) == 1) result[[1]] else result)
 }
 
-
 confidenceEllipse <- function (model, ...) {
 	UseMethod("confidenceEllipse")
 }
 
-confidenceEllipse.lm <- function(model, which.coef, levels=0.95, Scheffe=FALSE, 
+confidenceEllipse.lm <- function(model, which.coef, levels=0.95, Scheffe=FALSE, dfn,
 		center.pch=19, center.cex=1.5, segments=51, xlab, ylab, 
 		col=palette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, ...){
 	which.coef <- if(length(coefficients(model)) == 2) c(1, 2)
@@ -130,9 +137,9 @@ confidenceEllipse.lm <- function(model, which.coef, levels=0.95, Scheffe=FALSE,
 				} else which.coef
 			}
 	coef <- coefficients(model)[which.coef]
-	xlab <- if (missing(xlab)) paste(names(coef)[1], "coefficient")
-	ylab <- if (missing(ylab)) paste(names(coef)[2], "coefficient")
-	dfn <- if (Scheffe) sum(df.terms(model)) else 2
+	if (missing(xlab)) xlab <- paste(names(coef)[1], "coefficient")
+	if (missing(ylab)) ylab <-  paste(names(coef)[2], "coefficient")
+	if (missing(dfn)) dfn <- if (Scheffe) sum(df.terms(model)) else 2
 	dfd <- df.residual(model)
 	shape <- vcov(model)[which.coef, which.coef]
 	levels <- rev(sort(levels))
@@ -150,7 +157,7 @@ confidenceEllipse.lm <- function(model, which.coef, levels=0.95, Scheffe=FALSE,
 }
 
 
-confidenceEllipse.glm <- function(model, which.coef, levels=0.95, Scheffe=FALSE, 
+confidenceEllipse.glm <- function(model, which.coef, levels=0.95, Scheffe=FALSE, dfn,
 		center.pch=19, center.cex=1.5, segments=51, xlab, ylab,
 		col=palette()[2], lwd=2, fill=FALSE, fill.alpha=0.3, draw=TRUE, add=!draw, ...){
 	which.coef <- if(length(coefficients(model)) == 2) c(1, 2)
@@ -162,7 +169,8 @@ confidenceEllipse.glm <- function(model, which.coef, levels=0.95, Scheffe=FALSE,
 	coef <- coefficients(model)[which.coef]
 	xlab <- if (missing(xlab)) paste(names(coef)[1], "coefficient")
 	ylab <- if (missing(ylab)) paste(names(coef)[2], "coefficient")
-	df <- if (Scheffe) sum(df.terms(model)) else 2
+	df <- if (!missing(dfn)) dfn
+			else if (Scheffe) sum(df.terms(model)) else 2
 	sumry <- summary(model, corr = FALSE)
 	shape <- vcov(model)[which.coef, which.coef]
 	levels <- rev(sort(levels))
