@@ -6,6 +6,8 @@
 # 14 April 2010: set id.n = 0. J. Fox
 # 15 August 2010 S. Weisberg, added col.lines and col arguments
 # 5 Sept 2010 J. Fox, pass ... down to plot() and points() etc.
+# 16 June 2011 allow layout=NA, in which case the layout is not set in this
+#  function, so it is the responsibility of the user
 
 
 # these functions to be rewritten; simply renamed for now
@@ -20,15 +22,17 @@ leveragePlots <- function(model, terms= ~ ., layout=NULL, ask,
 	nt <- length(good)
 	if (nt == 0) stop("No plots specified")
 	if (missing(main)) main <- if (nt == 1) "Leverage Plot" else "Leverage Plots"
-	if(is.null(layout)){
-		layout <- switch(min(nt,9), c(1,1), c(1,2), c(2,2), c(2,2),
-				c(3,2), c(3,2), c(3,3), c(3,3), c(3,3))}
-	nr <- 0
-	ask <- if(missing(ask) || is.null(ask)) prod(layout)<nt else ask
-	if(nt > 1){
-		op <- par(no.readonly=TRUE, oma=c(0, 0, 1.5, 0), 
-				mar=c(5, 4, 1, 2) + .1, mfrow=layout, ask=ask)
-		on.exit(par(op))}
+  nr <- 0  
+  if (nt > 1 & (is.null(layout) || is.numeric(layout))) {
+    if(is.null(layout)){
+         layout <- switch(min(nt, 9), c(1, 1), c(1, 2), c(2, 2), c(2, 2), 
+                             c(3, 2), c(3, 2), c(3, 3), c(3, 3), c(3, 3))
+    }
+    ask <- if(missing(ask) || is.null(ask)) prod(layout)<nt else ask
+    op <- par(mfrow=layout, ask=ask, no.readonly=TRUE, 
+            oma=c(0, 0, 1.5, 0), mar=c(5, 4, 1, 2) + .1)
+    on.exit(par(op))
+    }
 	for (term in good) leveragePlot(model, term, main="", ...)
 	mtext(side=3,outer=TRUE,main, cex=1.2)
 	invisible(0)
